documentStore.SrbDocumentStore

|  | ## Cheshire3 Object Model: Class SrbDocumentStore

Module documentStore :: Class SrbDocumentStore

## Class SrbDocumentStore
source code

Object Tree:

                       object --+
                                |
            configParser.C3Object --+
                                    |
                   baseStore.SrbStore --+
                                        |
               object --+               |
                        |               |
    configParser.C3Object --+           |
                            |           |
                  ObjectStore --+       |
                                |       |
        baseObjects.DocumentStore --+   |
                                    |   |
                  SimpleDocumentStore --+
                                        |
                                       SrbDocumentStore

Instance Methods

__init__(self, session, node, parent)
Inherited from `baseStore.SrbStore`: `begin_storing`, `clean`, `commit_storing`, `delete_item`, `fetch_checkSum`, `fetch_data`, `fetch_idList`, `fetch_size`, `generate_id`, `store_checkSum`, `store_data`, `verify_checkSum` Inherited from `baseStore.SrbStore` (private): `_closeContainer`, `_openContainer` Inherited from `SimpleDocumentStore`: `create_document`, `delete_document`, `fetch_document`, `store_document` Inherited from `baseObjects.DocumentStore`: `fetch_documentList` Inherited from `baseObjects.ObjectStore`: `create_object`, `delete_object`, `fetch_object`, `store_object` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `baseStore.SrbStore`: `checkSumHash`, `connection`, `currentId`, `dn`, `domain`, `host`, `passwd`, `port`, `resource`, `subcollection`, `user` Inherited from `SimpleDocumentStore`: `inPreParser`, `inWorkflow`, `outPreParser`, `outWorkflow` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, node, parent) (Constructor) | source code
Overrides: baseStore.SrbStore.__init__